@@ -8,10 +8,8 @@ import hashlib
 
 try:
     from urllib import urlencode
-    from urlparse import urljoin
 except ImportError:
     from urllib.parse import urlencode
-    from urllib.parse import urljoin
 
 try:
     from Crypto.Cipher import AES
@@ -30,6 +28,8 @@ BUY_ORDERBOOK = 'buy'
 SELL_ORDERBOOK = 'sell'
 BOTH_ORDERBOOK = 'both'
 
+TRADE_FEE = 0.0025
+
 TICKINTERVAL_ONEMIN = 'oneMin'
 TICKINTERVAL_FIVEMIN = 'fiveMin'
 TICKINTERVAL_HOUR = 'hour'
@@ -74,7 +74,8 @@ def encrypt(api_key, api_secret, export=True, export_fn='secrets.json'):
 def using_requests(request_url, apisign):
     return requests.get(
         request_url,
-        headers={"apisign": apisign}
+        headers={"apisign": apisign},
+        timeout=10
     ).json()
 
 
@@ -154,7 +155,7 @@ class Bittrex(object):
 
             return self.dispatch(request_url, apisign)
 
-        except:
+        except Exception:
             return {
                 'success': False,
                 'message': 'NO_API_RESPONSE',
@@ -167,7 +168,7 @@ class Bittrex(object):
         at Bittrex along with other meta data.
 
         1.1 Endpoint: /public/getmarkets
-        2.0 Endpoint: /pub/Markets/GetMarkets
+        2.0 NO Equivalent
 
         Example ::
             {'success': True,
@@ -192,7 +193,6 @@ class Bittrex(object):
         """
         return self._api_query(path_dict={
             API_V1_1: '/public/getmarkets',
-            API_V2_0: '/pub/Markets/GetMarkets'
         }, protection=PROTECTION_PUB)
 
     def get_currencies(self):
@@ -218,7 +218,7 @@ class Bittrex(object):
 
         Endpoints:
         1.1 /public/getticker
-        2.0 NO EQUIVALENT -- but get_candlesticks gives comparable data
+        2.0 NO EQUIVALENT -- but get_latest_candle gives comparable data
 
         :param market: String literal for the market (ex: BTC-LTC)
         :type market: str
@@ -245,7 +245,7 @@ class Bittrex(object):
             API_V2_0: '/pub/Markets/GetMarketSummaries'
         }, protection=PROTECTION_PUB)
 
-    def get_marketsummary(self, market):
+    def get_market_summary(self, market):
         """
         Used to get the last 24 hour summary of all active
         exchanges in specific coin
@@ -268,7 +268,7 @@ class Bittrex(object):
         """
         Used to get retrieve the orderbook for a given market.
 
-        The depth_type parameter is IGNORED under v2.0 and both orderbooks are aleways returned
+        The depth_type parameter is IGNORED under v2.0 and both orderbooks are always returned
 
         Endpoint:
         1.1 /public/getorderbook
@@ -295,7 +295,7 @@ class Bittrex(object):
 
         Endpoint:
         1.1 /market/getmarkethistory
-        2.0 /pub/Market/GetMarketHistory
+        2.0 NO Equivalent
 
         Example ::
             {'success': True,
@@ -318,7 +318,6 @@ class Bittrex(object):
         """
         return self._api_query(path_dict={
             API_V1_1: '/public/getmarkethistory',
-            API_V2_0: '/pub/Market/GetMarketHistory'
         }, options={'market': market, 'marketname': market}, protection=PROTECTION_PUB)
 
     def buy_limit(self, market, quantity, rate):
@@ -359,7 +358,7 @@ class Bittrex(object):
 
         :param market: String literal for the market (ex: BTC-LTC)
         :type market: str
-        :param quantity: The amount to purchase
+        :param quantity: The amount to sell
         :type quantity: float
         :param rate: The rate at which to place the order.
             This is not needed for market orders
@@ -486,7 +485,7 @@ class Bittrex(object):
             API_V2_0: '/key/balance/getdepositaddress'
         }, options={'currency': currency, 'currencyname': currency}, protection=PROTECTION_PRV)
 
-    def withdraw(self, currency, quantity, address):
+    def withdraw(self, currency, quantity, address, paymentid=None):
         """
         Used to withdraw funds from your account
 
@@ -500,13 +499,16 @@ class Bittrex(object):
         :type quantity: float
         :param address: The address where to send the funds.
         :type address: str
+        :param paymentid: Optional argument for memos, tags, or other supplemental information for cryptos such as XRP.
+        :type paymentid: str
         :return:
         :rtype : dict
         """
         return self._api_query(path_dict={
             API_V1_1: '/account/withdraw',
             API_V2_0: '/key/balance/withdrawcurrency'
-        }, options={'currency': currency, 'quantity': quantity, 'address': address}, protection=PROTECTION_PRV)
+        }, options={'currency': currency, 'quantity': quantity, 'address': address, 'paymentid': paymentid}
+            if paymentid else None, protection=PROTECTION_PRV)
 
     def get_order_history(self, market=None):
         """
@@ -514,7 +516,7 @@ class Bittrex(object):
 
         Endpoint:
         1.1 /account/getorderhistory
-        2.0 /key/orders/getorderhistory
+        2.0 /key/orders/getorderhistory or /key/market/GetOrderHistory
 
         :param market: optional a string literal for the market (ie. BTC-LTC).
             If omitted, will return for all markets
@@ -522,10 +524,16 @@ class Bittrex(object):
         :return: order history in JSON
         :rtype : dict
         """
-        return self._api_query(path_dict={
-            API_V1_1: '/account/getorderhistory',
-            API_V2_0: '/key/orders/getorderhistory'
-        }, options={'market': market, 'marketname': market} if market else None, protection=PROTECTION_PRV)
+        if market:
+            return self._api_query(path_dict={
+                API_V1_1: '/account/getorderhistory',
+                API_V2_0: '/key/market/GetOrderHistory'
+            }, options={'market': market, 'marketname': market}, protection=PROTECTION_PRV)
+        else:
+            return self._api_query(path_dict={
+                API_V1_1: '/account/getorderhistory',
+                API_V2_0: '/key/orders/getorderhistory'
+            }, protection=PROTECTION_PRV)
 
     def get_order(self, uuid):
         """
@@ -632,7 +640,7 @@ class Bittrex(object):
 
     def get_pending_withdrawals(self, currency=None):
         """
-        Used to view your pending withdrawls
+        Used to view your pending withdrawals
 
         Endpoint:
         1.1 NO EQUIVALENT
@@ -640,7 +648,7 @@ class Bittrex(object):
 
         :param currency: String literal for the currency (ie. BTC)
         :type currency: str
-        :return: pending widthdrawls in JSON
+        :return: pending withdrawals in JSON
         :rtype : list
         """
         return self._api_query(path_dict={
@@ -765,7 +773,7 @@ class Bittrex(object):
 
     def get_candles(self, market, tick_interval):
         """
-        Used to get all tick candle for a market.
+        Used to get all tick candles for a market.
 
         Endpoint:
         1.1 NO EQUIVALENT
@@ -791,7 +799,7 @@ class Bittrex(object):
                    BV: 1012.63286332 }]
             }
 
-        :return: Available tick candle in JSON
+        :return: Available tick candles in JSON
         :rtype: dict
         """
 
